RESP documentation

RESP version 2.2

This documentation is based on the Amber8 & Amber9 manuals. Additional pieces of information have been added to update the former documentation version. Few modifications have also been carried out to try to better describe the inputs of the RESP program as well.

Introduction

Input

-1st line-

-2nd section-

-3rd line-

-4th line-

-5th line-

-6th area-

-7th area- intra-molecular charge constraint(s)

-8th area- inter-molecular charge constraint(s)

-9th area- inter-structure charge equivalencing

Other file formats

input of replacement charges

input of new weight factors

input of MEP and coordinates

-1st line-

-2nd line up to n_atoms+1 line-

-n_atoms+2 line up to n_atoms+2+n_MEP_points line-

Description of some Fortran formats

Examples of inputs

References

Download the RESP program & patches

Introduction

Usage:

resp [-O] -i input -o output -p punch -q qin -t qout -e espot -w qwts -s esout

-O Overwrite output files if they exist.

The RESP (Restrained ElectroStatic Potential) program fits the quantum mechanically calculated molecular electrostatic potential (MEP) at molecular surfaces using an atom-centered point charge model. This method was developed primarily by Bayly. [1-3] A quantum mechanical program such as Gaussian, [4] Jaguar, [5] GAMESS, [6] or Firefly [7] must be used to generate the MEP input(s) for RESP.

- Note that the Antechamber program automates most of this process: [8] use the -fo gcrt option to create a Gaussian input file; then run Gaussian; then use the -fi gout -c resp option to automatically create the RESP input file and run a two-stage fitting procedure. If you don't use Gaussian, you can still run respgen to automatically create the input files needed for RESP.

- Other alternatives are to use the RESP ESP charge Derive (R.E.D.) tools, [9,10] and/or R.E.D. Server [11] to create RESP inputs, generate force field libraries and to manage the calculations. Examples of RESP and ESP charge derivation and force field libraries are available in the RESP ESP charge DDataBase (R.E.DD.B.). [12] See http://q4md-forcefieldtools.org for information about these options.

file name | flag | fortran unit |  | purpose

-------------------------------------------------------------------------------------------------------

input | -i | 5 | required | input options
output | -o | 6 | always produced | output of results
punch | -p | 7 | always produced | synopsis of results
qin | -q | 3 | optional | replacement charges
qout | -t | 19 | always produced | output of current charges
espot | -e | 10 | required | input of MEP and coordinates
|  |  |  | (note: these must be in atomic units)
qwts | -w | 4 | optional | input of new weight factors
esout | -s | 20 | optional | generated MEP values for new charges

-------------------------------------------------------------------------------------------------------

Input

Input included in the "-i" file (see examples at the end)

-1st line-

TITLE | a character string

-2nd section-

Begin with namelist " &cntrl"

inopt | = | 0 | normal run
| = | 1 | cycle through a list of different "qwt" read from -w unit

ioutopt | = | 0 | normal run
| = | 1 | write restart info of new MEP to -s unit

iqopt | = | 1 | reset all initial charges to zero (default)
| = | 2 | read in new initial charges from -q unit
| = | 3 | read in new initial charges from -q unit and perform averaging of those new initial charges according to "ivary" values (normally not used)

nmol | = | the number of structure(s) in a multiple structure fit (default 1) structure(s) = orientation(s), conformation(s) or molecule(s)

ihfree | = | 0 | all atoms are restrained
| = | 1 | hydrogens not restrained (default)

irstrnt | = | 0 | use of harmonic restraints (old style)
| = | 1 | use of hyperbolic restraints (default)
| = | 2 | only analysis of input charges; no charge fitting is carried out

qwt | = | normally use 0.0005 for Stage 1 - Amber force fields (default) use 0.01 for Stage 1 - Glycam force field
| = | normally use 0.001 for Stage 2 - Amber force fields (default) no Stage 2 - Glycam force field

End namelist " &cntrl" with " &end"

-3rd line-

wtmol | relative weight for the structure if multiple structure fit (1.0 otherwise)

-4th line-

subtitle for the structure (a character string)

-5th line-

charge | iuniq | total charge value & total number of atoms for the considered structure (in 2I5 format) |

-6th area-

one line for each atom:

Atomic number | ivary (in 2I5 format)

ivary |  |  |
| = | 0 | current charge fitted independently of other centers
| = | n | current charge fitted and equivalenced to that of center "n"
| = | -1 | current charge frozen at "initial stage" value typically read in from -q unit

*blank to end only if the number of structure(s) "nmol" is different from 1

-7th area-

intra-molecular charge constraint(s) (in I5,F10.5 format) blank line if no constraint

ngrp | = | the number of centers in the group of atoms associated with this constraint

grpchg | = | charge value to which the associated group of atoms (given on the next card) is to be constrained

-7.1th area-

imol | iatom | structure & atom indices (in 16I5 format)

the list ("ngrp" long) of the atom indices of those atoms to be constrained to the charge specified on the previous line.

*blank to end

-8th area-

inter-molecular charge constraint(s)

same format as intra-molecular charge constraint(s) - see the 7th & 7.1th areas

*blank to end

-9th area-

multiple structure atom charge equivalencing

format is similar to 7th & 7.1 areas

ngrp (in I5 format)

and then, on separate lines:

imol | iatom (in 16I5 format)

*blank to end

Other file formats

-q | input of replacement charges if requested (in 8F10.6 format) (note same format as that produced by -t unit)

-w | input new weight factors if requested

input | qwt | number of new weights to cycle thru (in I5 format)

input | new weights ("nqwt" lines in F10.5 format)

-e | input of MEP and coordinates

-1st line-

n_atoms n_MEP_points (total number of atoms & MEP points, in 2I5 format)

-2nd line up to n_atoms+1 line-

atom coordinates X Y Z (in Bohrs, in 17X,3E16.7 format)

-n_atoms+2 line up to n_atoms+2+n_MEP_points line-

MEP & coordinates

qpot X Y Y (in a.u. & Bohrs, in 1X,4E16.7 format)

Description of some Fortran formats

2I5 format 2 blocks of 5 characters (I = integer)

16I5 format 16 blocks of 5 characters (I = integer)

F10.5 format A block of 10 characters long (F = float) with 5 digits after the decimal point

17X,3E16.7 format A block of 17 space characters long followed by 3 blocks of 16 characters long with 7 digits after the decimal point (using the scientific E notation)

1X,4E16.7 format A space character followed by 4 blocks of 16 characters long with 7 digits after the decimal point (using the scientific E notation)

Examples of inputs

Several examples of input and output files are available in $AMBERHOME/examples/resp_charge_fit; these should be consulted by those interested in running the program.

See R.E.DD.B. as well. In each R.E.DD.B. project, the RESP inputs used in the reported charge fitting step are provided. See: http://q4md-forcefieldtools.org/REDDB/projects/REDDB-code/input$X.in (where "REDDB-code" and "$X" are the R.E.DD.B. code and the number of stages of the charge fitting step, respectively). Examples:

- Single orientation/single conformation/single molecule RESP fit (Amber force fields):

W-1 R.E.DD.B. project: input1.in & input2.in

- Multiple orientation/single conformation/multiple molecule RESP fit (Amber force fields):

W-46 R.E.DD.B. project: input1.in & input2.in

- Use of intra-molecular charge constraints in RESP charge fitting (Amber force fields):

F-1 R.E.DD.B. project: input1.in & input2.in

- Use of inter-molecular charge constraints & inter-molecular atom charge equivalencing in RESP charge fitting (Amber force fields):

F-60 R.E.DD.B. project: input1.in & input2.in

- Use of intra-molecular charge constraints, inter-molecular charge constraints & inter-molecular atom charge equivalencing in RESP charge fitting (Glycam force field):

F-71 R.E.DD.B. project: input1.in

- Use of intra-molecular charge constraints, inter-molecular charge constraints & inter-molecular atom charge equivalencing in RESP charge fitting (Amber force fields):

F-74 R.E.DD.B. project: input1.in & input2.in

- Use of intra-molecular charge constraints, inter-molecular charge constraints & inter-molecular atom charge equivalencing in RESP charge fitting (Amber force fields):

F-85 R.E.DD.B. project: input1.in & input2.in

etc...

References

[1] C.I. Bayly, P. Cieplak, W.D. Cornell & P.A. Kollman. A Well-Behaved Electrostatic Potential Based Method Using Charge Restraints For Determining Atom-Centered Charges: The RESP Model. J. Phys. Chem. 1993, 97, 10269-10280.

[2] W.D. Cornell, P. Cieplak, C.I. Bayly & P.A. Kollman. Application of RESP charges to calculate conformational energies, hydrogen bond energies and free energies of solvation. J. Am. Chem. Soc. 1993, 115, 9620-9631.

[3] P. Cieplak, W.D. Cornell, C. Bayly & P.A. Kollman. Application of the multimolecule and multiconformational RESP methodology to biopolymers: Charge derivation for DNA, RNA and proteins. J. Comput. Chem. 1995, 16, 1357-1377.

[4] http://www.gaussian.com/

[5] http://www.schrodinger.com/

[6] http://www.msg.chem.iastate.edu/gamess/

[7] http://classic.chem.msu.su/gran/gamess/

[8] J. Wang, W. Wang, P. A. Kollman & D. A. Case, Automatic atom type and bond type perception in molecular mechanical calculations, J. Mol. Graph. Model. 2006, 25, 247-260. http://ambermd.org/antechamber/antechamber.html

[9] A. Pigache, P. Cieplak & F.-Y. Dupradeau, Automatic and highly reproducible RESP and ESP charge derivation: Application to the development of programs RED and X RED, 227th ACS National Meeting, Anaheim, CA, USA, March 28 - April 1, 2004, http://q4md-forcefieldtools.org/RED/.

[10] F.-Y. Dupradeau, A. Pigache, T. Zaffran, C. Savineau, R. Lelong, N. Grivel, D. Lelong, W. Rosanski & P. Cieplak, The R.E.D. tools: Advances in RESP and ESP charge derivation and force field library building, Phys. Chem. Chem. Phys. 2010, 12, 7821-7839, [PMCID].

[11] E. Vanquelef, S. Simon, G. Marquant, E. Garcia, G. Klimerak, J. C. Delepine, P. Cieplak and F.-Y. Dupradeau, R.E.D. Server: a web service for deriving RESP and ESP charges and building force field libraries for new molecules and molecular fragment, Nucl. Acids Res. (Web server issue) 2011, W511-W517, http://q4md-forcefieldtools.org/REDS/ & [PMCID].

[12] F.-Y. Dupradeau, C. Cezard, R. Lelong, E. Stanislawiak, J. Pecher, J. C. Delepine & P. Cieplak, R.E.DD.B.: A database for RESP and ESP atomic charges, and force field libraries, Nucl. Acids Res. (Database issue) 2008, D360-D367, http://q4md-forcefieldtools.org/REDDB/ & [PMCID].

Download the RESP program & patches

. Download the standalone version of the RESP program version 2.1 from q4md-forfieldtools.org: the README-2.1 file & the corresponding package with this documentation.

. Download a patch to increase the maximal number of MEP points defined in the "espot" file (resp 2.1).

. Download the standalone version of the RESP program version 2.2 from q4md-forfieldtools.org: the README-2.2 file & the corresponding package with this documentation.

Last update of this RESP documentation: December 1st, 2011